<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2010 Robert Heel <rheel@1drop.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 * Hint: use extdeveval to insert/update function index above.
 */

require_once(PATH_tslib.'class.tslib_pibase.php');


/**
 * Plugin 'Openstreetmap' for the 'ods_osm' extension.
 *
 * @author	Robert Heel <rheel@1drop.de>
 * @package	TYPO3
 * @subpackage	tx_odsosm
 */
class tx_odsosm_pi1 extends tslib_pibase {
	var $prefixId      = 'tx_odsosm_pi1';		// Same as class name
	var $scriptRelPath = 'pi1/class.tx_odsosm_pi1.php';	// Path to this script relative to the extension dir.
	var $extKey        = 'ods_osm';	// The extension key.
	var $pi_checkCHash = true;

	var $config;

	function init($conf){
		$this->conf=$conf;
		$this->pi_setPiVarDefaults();
		$this->pi_loadLL();
		$this->pi_initPIflexForm(); // Init FlexForm configuration for plugin

		/* --------------------------------------------------
			Configuration (order of priority)
			- FlexForm
			- TypoScript
		-------------------------------------------------- */

		$flex=array();
		$options=array('height','marker','render','show_navigation','show_pan_zoom_bar','width','zoom');
		foreach($options as $option){
			$value=$this->pi_getFFvalue($this->cObj->data['pi_flexform'],$option,'sDEF');
			if($value){
				switch($option){
					default:
						$flex[$option]=$value;
					break;
				}
			}
		}
		$this->config=array_merge($conf,$flex);

		$this->config['id']='osm_'.$this->cObj->data['uid'];
	}

	/**
	 * The main method of the PlugIn
	 *
	 * @param	string		$content: The PlugIn content
	 * @param	array		$conf: The PlugIn configuration
	 * @return	The content that is displayed on the website
	 */
	function main($content, $conf) {
		$this->init($conf);

		/* ==================================================
			Header
		================================================== */
		$GLOBALS['TSFE']->additionalHeaderData[$this->prefixId]='
<script src="http://www.openlayers.org/api/OpenLayers.js" type="text/javascript"></script>
<script src="http://www.openstreetmap.org/openlayers/OpenStreetMap.js" type="text/javascript"></script>
';
//<script src="'.t3lib_extMgm::siteRelPath($this->extKey).'res/main.js" type="text/javascript"></script>
		$GLOBALS['TSFE']->JSeventFuncCalls['onload'][] = $this->config['id']."();";

		/* ==================================================
			Marker
		================================================== */
		$jsMarker='';
		$res=$GLOBALS['TYPO3_DB']->exec_SELECTquery('tx_odsosm_lat,tx_odsosm_lon','tt_address','uid IN ('.$this->config['marker'].')'.$this->cObj->enableFields('tt_address'));
		while($row=$GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)){
			$lat=$row['tx_odsosm_lat'];
			$lon=$row['tx_odsosm_lon'];
			$jsMarker.=$this->getMapMarker($lat,$lon);
		}

		/* ==================================================
			Map
		================================================== */
		$GLOBALS['TSFE']->additionalHeaderData[]="
<script type=\"text/javascript\">
	function ".$this->config['id']."(){".
		$this->getMapMain().
		$this->getMapCenter($lat,$lon).
		"var layerMarkers = new OpenLayers.Layer.Markers('Markers');".
		$jsMarker."
		map.addLayer(layerMarkers);
	}
</script>
";

		/* ==================================================
			Map container
		================================================== */
		$content='<div style="width:'.$this->config['width'].'px; height:'.$this->config['height'].'px;" id="'.$this->config['id'].'"></div>';

		return $this->pi_wrapInBaseClass($content);
	}

	function getMapMain(){
		return("
			var map; //complex object of type OpenLayers.Map
			map = new OpenLayers.Map ('".$this->config['id']."', {
				controls:[".($this->config['show_navigation'] ? "new OpenLayers.Control.Navigation()," : "").($this->config['show_pan_zoom_bar'] ? "new OpenLayers.Control.PanZoomBar()," : "")."new OpenLayers.Control.Attribution()],
				maxExtent: new OpenLayers.Bounds(-20037508.34,-20037508.34,20037508.34,20037508.34),
				maxResolution: 156543.0399,
				numZoomLevels: 19,
				units: 'm',
				projection: new OpenLayers.Projection('EPSG:900913'),
				displayProjection: new OpenLayers.Projection('EPSG:4326')
			} );
			var layerMain = new OpenLayers.Layer.OSM.".$this->config['render'].";
			map.addLayer(layerMain);
		");
	}

	function getMapCenter($lat,$lon){
		return("
			var lonLat = new OpenLayers.LonLat(".$lon.",".$lat.").transform(new OpenLayers.Projection('EPSG:4326'), map.getProjectionObject());
			map.setCenter(lonLat,".$this->config['zoom'].");
		");
	}

	function getMapMarker($lat,$lon){
		return("
			var lonLat = new OpenLayers.LonLat(".$lon.",".$lat.").transform(new OpenLayers.Projection('EPSG:4326'), map.getProjectionObject());
			var size = new OpenLayers.Size(21,25);
			var offset = new OpenLayers.Pixel(-(size.w/2), -size.h);
			var icon = new OpenLayers.Icon('http://www.openstreetmap.org/openlayers/img/marker.png',size,offset);
			layerMarkers.addMarker(new OpenLayers.Marker(lonLat,icon));
		");
	}
}



if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/ods_osm/pi1/class.tx_odsosm_pi1.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/ods_osm/pi1/class.tx_odsosm_pi1.php']);
}

?>